#include <stdlib.h>
#include <strings.h>
#include <string.h>
#include <stdio.h>

int which_scale(string_t scale);
float celsius_to_fahrenheit(float c_temp);
float fahrenheit_to_celsius(float f_temp);

enum {
    SCALE_F = 1,  /* constant value for Fahrenheit */
    SCALE_C = 2   /* constant value for Celsius */
};

float celsius_to_fahrenheit(float c_temp) {
    float f_temp = 0.0;
    f_temp = (1.8 * c_temp) + 32;
    return f_temp;
}

float fahrenheit_to_celsius(float f_temp) {
    float c_temp = 0.0;
    c_temp = (f_temp - 32) / 1.8;
    return c_temp;
}

int which_scale(string_t scale) {

    /* return SCALE_F if the temperature scale is Fahrenheit or
       F; use strcasecmp for case insensitive comparisons */

    if (strcasecmp(scale, "Fahrenheit") == 0 ||
        strcasecmp(scale, "F") == 0) {
        return SCALE_F;
    }

    /* return SCALE_C if the temperature scale is Celsius or
       C; use strcasecmp for case insensitive comparisons */

    if (strcasecmp(scale, "Celsius") == 0 ||
        strcasecmp(scale, "C") == 0) {
        return SCALE_C;
    }

    return -1;
}

int main (int argc, string_t argv[]) {
    string_t temp_raw, scale_in_raw, scale_out_raw;
    int scale_in = -1, scale_out = -1;
    float temp_in = 0.0, temp_out = 0.0;

    if (argc < 4) {
        printf("Please specify the temperature and scales.\n");
        exit(1);
    }

    temp_raw = argv[1];
    scale_in_raw = argv[2];
    scale_out_raw = argv[3];

    /* check if the specified input temperature contained a
       valid number */

    if (sscanf(temp_raw, "%f", &temp_in) != 1) {
        printf("Invalid input temperature: '%s' degrees\n",
               temp_raw);
        exit(1);
    }

    /* verify that the input temperature scale was either
       Fahrenheit or Celsius */

    scale_in = which_scale(scale_in_raw);
    if (scale_in != SCALE_F && scale_in != SCALE_C) {
        printf("Invalid input temperature scale: '%s'\n",
               scale_in_raw);
        exit(1);
    }

    /* verify that the output temperature scale was either
       Fahrenheit or Celsius */

    scale_out = which_scale(scale_out_raw);
    if (scale_out != SCALE_F && scale_out != SCALE_C) {
        printf("Invalid output temperature scale: '%s'\n",
               scale_out_raw);
        exit(1);
    }

    if (scale_in == scale_out) {
       printf("Input and output scales are the same\n");
       exit(1);
    }

    /* if the input scale is Celsius and the output scale
       is Fahrenheit, use the celsius_to_fahrenheit function
       to convert the temperature */

    if (scale_in == SCALE_C && scale_out == SCALE_F) {
        temp_out = celsius_to_fahrenheit(temp_in);
        printf("%0.2f degrees C is %0.2f degrees F\n",
               temp_in, temp_out);
        exit(0);
    }

    /* if the input scale is Fahrenheit and the output scale
       is Celsius, use the fahrenheit_to_celsius function
       to convert the temperature */

    if (scale_in == SCALE_F && scale_out == SCALE_C) {
        temp_out = fahrenheit_to_celsius(temp_in);
        printf("%0.2f degrees F is %0.2f degrees C\n",
               temp_in, temp_out);
        exit(0);
    }

    exit(1);
}

